@@ -1,16 +1,15 @@
 import logging
+from typing import NamedTuple, Union
 
 import numpy
 import pandas
-from scipy.special._ufuncs import inv_boxcox
-from scipy.stats import boxcox
 from statsmodels.tsa.holtwinters import ExponentialSmoothing
 from statsmodels.tsa.statespace.sarimax import SARIMAX
 
-from hts._t import ModelT, TimeSeriesModelT, TransformT
+from hts._t import ModelT, NAryTreeT, TimeSeriesModelT, TransformT
 from hts.core.exceptions import InvalidArgumentException
 from hts.hierarchy import HierarchyTree
-from hts.transforms import FunctionTransformer
+from hts.transforms import BoxCoxTransformer, FunctionTransformer
 
 logger = logging.getLogger(__name__)
 
@@ -21,7 +20,7 @@ class TimeSeriesModel(TimeSeriesModelT):
     """
 
     def __init__(
-        self, kind: str, node: HierarchyTree, transform: TransformT = None, **kwargs
+        self, kind: str, node: HierarchyTree, transform: TransformT = False, **kwargs
     ):
         """
         Parameters
@@ -43,40 +42,56 @@ class TimeSeriesModel(TimeSeriesModelT):
 
         self.kind = kind
         self.node = node
+        self.transform_function = self._set_transform(transform=transform)
         self.model = self.create_model(**kwargs)
         self.forecast = None
         self.residual = None
         self.mse = None
 
-        self.transform = transform
-        if self.transform:
-            if transform is True:
-                self.transformer = FunctionTransformer(func=boxcox, inv_func=inv_boxcox)
-            else:
-                self.transformer = FunctionTransformer(
-                    func=transform.func, inv_func=transform.inv_func
+    def _set_transform(self, transform: TransformT):
+        if transform is False or transform is None:
+            return FunctionTransformer(func=self._no_func, inv_func=self._no_func)
+        elif transform is True:
+            return BoxCoxTransformer()
+        elif isinstance(transform, NamedTuple):
+            if not hasattr(transform, "func") or not hasattr(transform, "inv_func"):
+                raise ValueError(
+                    "If passing a NamedTuple, it must have a `func` and `inv_func` parameters"
                 )
+            return FunctionTransformer(
+                func=getattr(transform, "func"), inv_func=getattr(transform, "inv_func")
+            )
         else:
-            self.transformer = FunctionTransformer(
-                func=self._no_func, inv_func=self._no_func
+            raise ValueError(
+                "Invalid transform passed. Use either `True` for default boxcox transform or "
+                "a `NamedTuple(func: Callable, inv_func: Callable)` for custom transforms"
             )
 
-    @staticmethod
-    def _no_func(x):
-        return x, None
-
     def _set_results_return_self(self, in_sample, y_hat):
+        in_sample = self.transform_function.inverse_transform(in_sample)
+        y_hat = self.transform_function.inverse_transform(y_hat)
         self.forecast = pandas.DataFrame(
             {"yhat": numpy.concatenate([in_sample, y_hat])}
         )
-        self.residual = (in_sample - self.node.get_series()).values
+        self.residual = (in_sample - self._get_transformed_data(as_series=True)).values
         self.mse = numpy.mean(numpy.array(self.residual) ** 2)
         return self
 
+    def _get_transformed_data(
+        self, as_series: bool = False
+    ) -> Union[pandas.DataFrame, pandas.Series]:
+        key = self.node.key
+        value = self.node.item
+        transformed = self.transform_function.transform(value[key])
+        if as_series:
+            return pandas.Series(transformed)
+        else:
+            return pandas.DataFrame({key: transformed})
+
     def create_model(self, **kwargs):
 
         if self.kind == ModelT.holt_winters.name:
-            data = self.node.item
+            data = self._get_transformed_data()
             model = ExponentialSmoothing(endog=data, **kwargs)
 
         elif self.kind == ModelT.auto_arima.name:
@@ -92,7 +107,7 @@ class TimeSeriesModel(TimeSeriesModelT):
 
         elif self.kind == ModelT.sarimax.name:
             as_df = self.node.item
-            end = self.node.get_series()
+            end = self._get_transformed_data(as_series=True)
             if self.node.exogenous:
                 ex = as_df[self.node.exogenous]
             else:
