@@ -10,11 +10,8 @@ from sklearn.base import BaseEstimator, TransformerMixin
 logger = logging.getLogger(__name__)
 
 
-class FunctionTransformer(BaseEstimator, TransformerMixin):
-    def __init__(self, func: callable = boxcox, inv_func: callable = inv_boxcox):
-
-        self.func = func
-        self.inv_func = inv_func
+class BoxCoxTransformer(BaseEstimator, TransformerMixin):
+    def __init__(self):
         self.lam = None
 
     def fit(self, x: pandas.Series, y=None, **fit_params):
@@ -23,12 +20,12 @@ class FunctionTransformer(BaseEstimator, TransformerMixin):
     def transform(self, x: pandas.Series):
         if any(x.values == 0):
             x += 1
-            x, self.lam = self.func(x.values)
+            x, self.lam = boxcox(x.values)
             return x
         elif any(x.values < 0):
             raise ValueError("Boxcox can\t be applied, column has negative values")
         else:
-            x, self.lam = self.func(x.values)
+            x, self.lam = boxcox(x.values)
             return x
 
     def fit_transform(self, x: pandas.Series, y=None, **fit_params):
@@ -36,6 +33,26 @@ class FunctionTransformer(BaseEstimator, TransformerMixin):
 
     def inverse_transform(self, x: Union[pandas.Series, numpy.ndarray]):
         if isinstance(x, pandas.Series):
-            return self.inv_func(x.values, self.lam)
+            return inv_boxcox(x.values, self.lam)
         else:
-            return self.inv_func(x, self.lam)
+            return inv_boxcox(x, self.lam)
+
+
+class FunctionTransformer(BaseEstimator, TransformerMixin):
+    def __init__(self, func: callable = None, inv_func: callable = None):
+        if not func or not inv_func:
+            raise ValueError("`func` and `inv_func` must be passed")
+        self.func = func
+        self.inv_func = inv_func
+
+    def fit(self, x: pandas.Series, y=None, **fit_params):
+        return self
+
+    def transform(self, x: pandas.Series):
+        return self.func(x.values)
+
+    def fit_transform(self, x: pandas.Series, y=None, **fit_params):
+        return self.fit(x).transform(x)
+
+    def inverse_transform(self, x: Union[pandas.Series, numpy.ndarray]):
+        return self.inv_func(x)
